@@ -1,14 +1,18 @@
 import numpy as np
-from tqdm import tqdm_notebook as tqdm
+from tqdm.notebook import tqdm
 import pandas as pd
 import geopandas as gpd
+import itertools
+from itertools import product,combinations
 
 from pysal.explore.giddy.markov import Markov
 import matplotlib.pyplot as plt
 import seaborn as sb
 
+from sandpyper.outils import getListOfFiles, getLoc
 
-def attach_trs_geometry(markov_transects_df, dirNameTrans):
+
+def attach_trs_geometry(markov_transects_df, dirNameTrans, list_loc_codes):
     """ Attach transect geometries to the transect-specific BCDs.
     Args:
         markov_transects_df (Pandas dataframe): Dataframe storing BCDs at the transect level.
@@ -24,9 +28,8 @@ def attach_trs_geometry(markov_transects_df, dirNameTrans):
 
         transect_in = gpd.read_file(i)
         transect_in.rename({'TR_ID': 'tr_id'}, axis=1, inplace=True)
-        loc = getLoc(i)
+        loc = getLoc(i,list_loc_codes)
 
-        print(f" Attaching {loc} ...")
         sub_markovs_trs = markov_transects_df.query(f"location=='{loc}'")
         sub_markovs_trs["geometry"] = pd.merge(
             sub_markovs_trs,
@@ -35,7 +38,6 @@ def attach_trs_geometry(markov_transects_df, dirNameTrans):
             on='tr_id')["geometry"].values
 
         return_df = pd.concat([return_df, sub_markovs_trs], ignore_index=True)
-    print(f" Done!")
     return return_df
 
 
@@ -386,6 +388,10 @@ def steady_state_transect(dataset, mode="nnn", unreal='drop', thresh=8, min_poin
         for tr_id in data_loc.tr_id.unique():
 
             data_tr = data_loc.query(f"tr_id=='{tr_id}'")
+
+            if data_tr.empty:
+                data_tr = data_loc.query(f"tr_id=={tr_id}")
+
             data_piv = data_tr.pivot(
                 values=field_markov_tags,
                 index=field_unique_id,
@@ -535,14 +541,14 @@ def compute_rBCD_transects(
 
         to_plot["location"] = loc
 
-        coastal_markov_trs_steady = attach_trs_geometry(to_plot, dirNameTrans)
+        coastal_markov_trs_steady = attach_trs_geometry(to_plot, dirNameTrans, list_loc_codes=loc_codes)
 
         piv_markov_trs = pd.pivot_table(
             coastal_markov_trs_steady, index=["location", "tr_id"],
             columns="process", values=["coastal_index"]).reset_index(col_level=1)
 
         piv_markov_trs.columns = piv_markov_trs.columns.droplevel(0)
-        trs_markov_idx = attach_trs_geometry(piv_markov_trs, dirNameTrans)
+        trs_markov_idx = attach_trs_geometry(piv_markov_trs, dirNameTrans, list_loc_codes=loc_codes)
 
         ss_transects_idx = pd.concat(
             [trs_markov_idx, ss_transects_idx], ignore_index=True)
@@ -554,3 +560,50 @@ def compute_rBCD_transects(
             pass
 
     return ss_transects_idx, to_plot
+
+
+def compute_multitemporal (df,
+                           date_field='survey_date',
+                          sand_label_field='label_sand',
+                          common_field="geometry"):
+
+
+
+    fusion_long=pd.DataFrame()
+
+    for location in full_dataset.location.unique():
+        print(f"working on {location}")
+        loc_data=full_dataset.query(f"location=='{location}'")
+        list_dates=loc_data.loc[:,date_field].unique()
+        list_dates.sort()
+
+
+        for i in tqdm(range(list_dates.shape[0])):
+
+            if i < list_dates.shape[0]-1:
+                date_pre=list_dates[i]
+                date_post=list_dates[i+1]
+                print(f"Calculating dt{i}, from {date_pre} to {date_post} in {location}.")
+
+                df_pre=loc_data.query(f"{date_field} =='{date_pre}' & {sand_label_field} == 0").dropna(subset=['z'])
+                df_post=loc_data.query(f"{date_field} =='{date_post}' & {sand_label_field} == 0").dropna(subset=['z'])
+
+                merged=pd.merge(df_pre,df_post, how='inner', on=common_field,validate="one_to_one",suffixes=('_pre','_post'))
+                merged["dh"]=merged.z_post.astype(float) - merged.z_pre.astype(float)
+
+                dict_short={"geometry": merged.geometry,
+                            "location":location,
+                            "tr_id":merged.tr_id_pre,
+                            "distance":merged.distance_pre,
+                            "dt":  f"dt_{i}",
+                            "date_pre":date_pre,
+                            "date_post":date_post,
+                            "z_pre":merged.z_pre.astype(float),
+                            "z_post":merged.z_post.astype(float),
+                            "dh":merged.dh}
+
+                short_df=pd.DataFrame(dict_short)
+                fusion_long=pd.concat([short_df,fusion_long],ignore_index=True)
+
+    print("done")
+    return fusion_long
