@@ -10,6 +10,8 @@ from matplotlib.ticker import FixedFormatter, FixedLocator, AutoMinorLocator
 from mpl_toolkits.axes_grid1.inset_locator import inset_axes
 
 import seaborn as sb
+from sandpyper.outils import round_special
+
 
 
 def getVol(dh):
@@ -268,8 +270,8 @@ def new_get_state_vol_table(sand_pts, lod, full_specs_table,
             else:
                 specs = table_details.query(f"loc_code=='{loc}' & dt=='{dt}'")
                 full_loc = specs.loc_full.values[0]
-                date_from = specs.date_from.values[0]
-                date_to = specs.date_to.values[0]
+                date_from = specs.date_pre.values[0]
+                date_to = specs.date_post.values[0]
                 n_days = specs.n_days.values[0]
 
             beach_length = len(data_in.columns) * transect_spacing
@@ -392,8 +394,8 @@ def new_get_transects_vol_table(sand_pts, lod, full_specs_table, transect_spacin
             if bool(full_specs_table):
                 specs = full_specs_table.query(f"loc_code=='{loc}' & dt=='{dt}'")
                 full_loc = specs.loc_full.values[0]
-                date_from = specs.date_from.values[0]
-                date_to = specs.date_to.values[0]
+                date_from = specs.date_pre.values[0]
+                date_to = specs.date_post.values[0]
                 n_days = specs.n_days.values[0]
             else:
                 pass
@@ -507,12 +509,18 @@ def new_plot_alongshore_change(sand_pts,
         if bool(full_specs_table) == False:
             skip_details = True
         else:
-            print("Please provide the path to the specs table.")
-    elif os.path.isfile(full_specs_table):
-        table_details = pd.read_csv(full_specs_table)
+            raise TypeError("Not a DataFrame, nor a valid path to the .csv file for the specs table.")
+    elif isinstance(full_specs_table, str):
+        if os.path.isfile(full_specs_table):
+            table_details = pd.read_csv(full_specs_table)
+            skip_details = False
+        else:
+            TypeError("The path provided in full_spec_table is not a valid path to the .csv file.")
+    elif isinstance(full_specs_table, pd.DataFrame):
+        table_details = full_specs_table
         skip_details = False
     else:
-        raise TypeError("Not a valid path to the .csv file for the specs table.")
+        raise TypeError("Not a DataFrame, nor a valid path to the .csv file for the specs table.")
 
     land_limits = pd.DataFrame(sand_pts.groupby(
         ["location"]).distance.max()).reset_index()
@@ -561,10 +569,10 @@ def new_plot_alongshore_change(sand_pts,
                 lod = 0.05
             else:
 
-                specs = table_details.query(f"loc_code=='{loc}' & dt=='{dt}'")
+                specs = table_details.query(f"location=='{loc}' & dt=='{dt}'")
                 full_loc = specs.loc_full.values[0]
-                date_from = specs.date_from.values[0]
-                date_to = specs.date_to.values[0]
+                date_from = specs.date_pre.values[0]
+                date_to = specs.date_post.values[0]
                 n_days = specs.n_days.values[0]
 
             if isinstance(lod, str):
@@ -747,11 +755,14 @@ def new_plot_alongshore_change(sand_pts,
     if return_data:
         return data_in_filled
 
-
 def plot_mec_evolution(volumetrics,
                        location_field,
+                       loc_order,
+                       date_from_field="date_pre",
+                       date_to_field="date_post",
                        date_format="%d.%m.%y",
                        scale_mode="equal",
+                       x_diff=None,
                        dates_step=50,
                        x_limits=(-0.41,
                                  0.41),
@@ -760,21 +771,11 @@ def plot_mec_evolution(volumetrics,
                                     4),
                        font_scale=0.75,
                        sort_locations=True,
-                       loc_order=["pfa",
-                                  "wbl",
-                                  "mar",
-                                  "apo",
-                                  "prd",
-                                  "leo",
-                                  "por",
-                                  "cow",
-                                  "inv",
-                                  "sea"],
                        dpi=300,
                        img_type=".png",
                        save_fig=False,
-                       name_fig=f"Normalised Dynamics in Victoria_bigfont",
-                       save_path='C:\\jupyter\\images_ch_4\\normalised_changes\\'):
+                       name_fig=f"Mean Elevation Changes",
+                       save_path=None):
     """
     Display and optionally save global volumetric timeseries plots, displaying period-specific Mean Elevation Change (mec, in m) and cumulative mec (since start of the monitoring), across lcoations.
 
@@ -783,6 +784,8 @@ def plot_mec_evolution(volumetrics,
         date_format (str): format to plot dates on y-axis. Default="%d.%m.%y".
         scale_mode (str) ("optimised","equal"): If "equal" (Default), all locations subplots will have the same x-axis ticks spacing (reccomended for comaprison purposes).
         If "optimised", an attempt to estimate the best tick steps to use by analysing absolute range of mec values.
+        x_diff (dict): In case a subplot x needs axis limits different to the others.
+        A dictionary with location codes as keys and a list containing the minimum and maximum x values for these locations.
         dates_step (int): Frequency of days between each tick in the y-axis (dates). Default=50.
         x_limits (tuple of floats): tuple containing min and max values of mec. Used to get unifor subplots widths.
         Note: currently, an exeption is hard-coded for Inverloch, which is one ad-hoc case used during code development. (TO BE UPDated)
@@ -816,11 +819,6 @@ def plot_mec_evolution(volumetrics,
     else:
         pass
 
-    # replace long location names with shorter versions
-
-    volumetrics.replace("Point Roadknight", "Pt. Roadk.", inplace=True)
-    volumetrics.replace("St. Leonards", "St. Leo.", inplace=True)
-
     num_subplots = volumetrics.location.unique().shape[0]
     if num_subplots > 1:
 
@@ -830,20 +828,19 @@ def plot_mec_evolution(volumetrics,
                                 figsize=figure_size)
 
         for ax_i, loc in zip(axs.flatten(), volumetrics.location.unique()):
-            #     print(ax,loc)
 
             data_in = volumetrics.query(f"location=='{loc}'")
-            data_in.sort_values("date_to", inplace=True)
+            data_in.sort_values(date_to_field, inplace=True)
             # add the cumulative change curve
             data_in["cum_change"] = data_in.norm_net_change.cumsum()
 
-            first_date_from = data_in.date_from.iloc[0]
+            first_date_from = data_in.loc[:, date_from_field].iloc[0]
 
             full_loc = data_in.loc[:, location_field].iloc[0]
             x = data_in.norm_net_change
             x2 = data_in.cum_change
-            y = dates.date2num(data_in.date_to)
-            y_scatter = dates.date2num(data_in.date_from)
+            y = dates.date2num(data_in.loc[:, date_to_field])
+            y_scatter = dates.date2num(data_in.loc[:, date_from_field])
 
             # LinePlots
 
@@ -874,7 +871,7 @@ def plot_mec_evolution(volumetrics,
 
             # ScatterPlots
             ax_i.scatter(x, y, c="k", s=5, zorder=5)
-            ax_i.scatter(0, first_date_from, c="k", s=5, zorder=5)
+            ax_i.scatter(0, y_start[0], c="k", s=5, zorder=5)
 
             # ticks
             if scale_mode == "optimised":
@@ -893,15 +890,17 @@ def plot_mec_evolution(volumetrics,
                         max(x), 0.05) + tick_step, tick_step)
                 ax_i.set_xticks(ticks_value)
 
-            elif scale_mode == "equal":             # Inverloch different scale, for display purposes
-                if loc != 'inv':
+            elif scale_mode == "equal":
+                if isinstance(x_diff,dict):
 
-                    ax_i.set_xlim(x_limits)
+                    if loc in x_diff.keys():
+                        print(f"x_diff provided. Setting xlims of {loc} = {x_diff[loc][0],x_diff[loc][1]} ")
+                        ax_i.set_xlim(x_diff[loc][0],x_diff[loc][1])
+                    else:
+                        print(f"x_diff provided but {loc} not found. Setting xlims= {x_limits} ")
+                        ax_i.set_xlim(x_limits)
                 else:
-                    ax_i.set_xlim(-1.1, 1.1)
-
-            else:
-                pass
+                    ax_i.set_xlim(x_limits)
 
             start, end = ax_i.get_ylim()
             ax_i.yaxis.set_ticks(np.arange(start, end, dates_step))
@@ -921,8 +920,6 @@ def plot_mec_evolution(volumetrics,
 
         fig, ax = plt.subplots(figsize=figure_size)
 
-    #     print(ax,loc)
-
         data_in = volumetrics
         data_in.sort_values("date_to", inplace=True)
         # add the cumulative change curve
@@ -1017,3 +1014,74 @@ def plot_mec_evolution(volumetrics,
         plt.savefig(savetxt, dpi=dpi)
     else:
         pass
+        
+def plot_single_loc (df,loc_subset,
+                    figsize,colors_dict,linewidth,out_date_format,
+                    xlabel,ylabel,suptitle):
+
+    f,ax=plt.subplots(figsize=figsize)
+
+    if isinstance(colors_dict, dict):
+        print("Color dictionary provided.")
+        color_mode="dictionary"
+
+    elif colors_dict == None:
+
+        num_colors=len(loc_subset)
+        cmapa = plt.cm.get_cmap('tab20c')
+        cs=[cmapa(i) for i in np.linspace(0, 0.5, num_colors)]
+        color_mode="auto"
+
+    else:
+        raise TypeError("Error in specifying color dictionary.")
+
+    dataset_in=df.query(f"location in {loc_subset}")
+
+    for i,location in enumerate(dataset_in.location.unique()):
+
+        dataset=dataset_in.query(f"location=='{location}'")
+
+        if color_mode=="dictionary":
+            color_i=colors_dict[location]
+        elif color_mode=="auto":
+            color_i=cs[i]
+
+        # Calculate the cumulative net volumetric change and mean elevation change from start of monitoring
+        dataset["cum"]=dataset.net_vol_change.cumsum()
+        dataset["cum_mec"]=dataset.norm_net_change.cumsum()
+
+        dataset["date_post"]=pd.to_datetime(dataset.date_post, dayfirst=False)
+        dataset["date_pre"]=pd.to_datetime(dataset.date_pre, dayfirst=False)
+
+        ax=sb.lineplot(data=dataset, x="date_post", color=color_i, y="net_vol_change",label=f"{location}: period",
+                      lw=linewidth)
+        ax=sb.lineplot(data=dataset, x="date_post", color=color_i, y="cum", label=f"{location}: cumulative",
+                       linestyle="--",lw=linewidth)
+
+        ax=sb.scatterplot(data=dataset, color=color_i, x="date_post", y="net_vol_change")
+        ax=sb.scatterplot(data=dataset, color=color_i, x="date_post", y="cum")
+
+        x_start=np.array([dataset.iloc[0].date_pre,dataset.iloc[0].date_post])
+        y_start=np.array([0,dataset.iloc[0].cum])
+
+        ax.plot(x_start,y_start, c=color_i)
+        ax.scatter(dataset.iloc[0].date_pre,0, c=color_i, marker="*")
+
+    # the zero horizontal line
+    ax.axhline(0,c="k",lw=0.5)
+
+    ax.set(xticks=np.append(dataset_in.date_pre.values,dataset_in.date_post.values[-1]))
+    ax.xaxis.set_major_formatter(dates.DateFormatter(out_date_format))
+
+    plt.xticks(rotation=90)
+
+    # the plot x and y axis labels
+    ax.set_xlabel(xlabel)
+    ax.set_ylabel(ylabel)
+
+
+    # the title of the plot
+    f.suptitle(suptitle);
+
+
+    return ax
